/*! nanakshahi-js v8.2.2 | Sarabveer Singh <me@sarabveer.me> | MPL-2.0 | https://github.com/Sarabveer/nanakshahi-js */
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define([], factory);
	else if(typeof exports === 'object')
		exports["nanakshahi"] = factory();
	else
		root["nanakshahi"] = factory();
})(this, () => {
return /******/ (() => { // webpackBootstrap
/******/ 	var __webpack_modules__ = ({

/***/ 56:
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var englishMonths = __webpack_require__(291);
var gurpurabs = __webpack_require__(855);
var months = __webpack_require__(373);
var movableGurpurabs = __webpack_require__(267);
var weekdays = __webpack_require__(861);
module.exports = {
  englishMonths: englishMonths,
  gurpurabs: gurpurabs,
  months: months,
  movableGurpurabs: movableGurpurabs,
  weekdays: weekdays
};

/***/ }),

/***/ 178:
/***/ ((module) => {

/**
 * Check if current year is Leap Year (Gregorian Leap Rule)
 * Uses optimized version from: https://stackoverflow.com/a/11595914
 * @param {number} nsYear Nanakshahi year to check for Leap
 * @return {boolean} True for Leap, False for Regular
 * @example leapYear( 555 )
 * @example leapYear( 556 )
 * @private
 */
module.exports = function (nsYear) {
  var year = nsYear + 1469;
  // eslint-disable-next-line no-bitwise
  return (year & 3) === 0 && (year % 25 !== 0 || (year & 15) === 0);
};

/***/ }),

/***/ 254:
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var _require = __webpack_require__(56),
  movableGurpurabs = _require.movableGurpurabs;

/**
 * Returns Gregorian Date of Movable Gurpurab from 2003CE - 2100CE
 * @param {string} gurpurab
 * Movable Gurpurabs:<br>
 * `gurunanak` - Parkash Guru Nanak Dev Ji<br>
 * `bandichhorr` - Bandi Chhorr Divas / Diwali<br>
 * `holla` - Holla Mahalla<br>
 * `kabeer` - Birthday Bhagat Kabeer Ji<br>
 * `ravidaas` - Birthday Bhagat Ravidaas Ji<br>
 * `naamdev` - Birthday Bhagat Naamdev Ji
 * @param {!number} [year] Gregorian year, default is current year. Range [2003...2100]
 * @return {Object} Gurpurab Date with Name in English and Punjabi
 * @example findMovableGurpurab( 'gurunanak' )
 */
function findMovableGurpurab(gurpurab) {
  var year = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : new Date().getFullYear();
  // Check if gurpurab in array
  if (!(gurpurab in movableGurpurabs)) {
    throw Error("String \"".concat(gurpurab, "\" not found in list of movable Gurpurabs."));
  }
  if (year < 2003 || year > 2100) {
    throw new RangeError('Year not in range [2003...2100].');
  }

  // Get data for event
  var _movableGurpurabs$gur = movableGurpurabs[gurpurab],
    name = _movableGurpurabs$gur.name,
    dates = _movableGurpurabs$gur.dates;
  var _dates = dates[year - 2003],
    month = _dates.month,
    day = _dates.day;
  return {
    gregorianDate: new Date(year, month - 1, day),
    name: {
      en: "".concat(name.en, " (").concat(year, ")"),
      pa: "".concat(name.pa, " (").concat(year, ")"),
      type: name.type,
      movable: true
    }
  };
}
module.exports = findMovableGurpurab;

/***/ }),

/***/ 267:
/***/ ((module) => {

module.exports = {
  bandichhorr: {
    dates: [{
      month: 10,
      day: 25
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 1
    }, {
      month: 10,
      day: 21
    }, {
      month: 11,
      day: 9
    }, {
      month: 10,
      day: 28
    }, {
      month: 10,
      day: 17
    }, {
      month: 11,
      day: 5
    }, {
      month: 10,
      day: 26
    }, {
      month: 11,
      day: 13
    }, {
      month: 11,
      day: 3
    }, {
      month: 10,
      day: 23
    }, {
      month: 11,
      day: 11
    }, {
      month: 10,
      day: 30
    }, {
      month: 10,
      day: 19
    }, {
      month: 11,
      day: 7
    }, {
      month: 10,
      day: 27
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 4
    }, {
      month: 10,
      day: 24
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 1
    }, {
      month: 10,
      day: 20
    }, {
      month: 11,
      day: 8
    }, {
      month: 10,
      day: 29
    }, {
      month: 10,
      day: 17
    }, {
      month: 11,
      day: 5
    }, {
      month: 10,
      day: 26
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 2
    }, {
      month: 10,
      day: 22
    }, {
      month: 11,
      day: 10
    }, {
      month: 10,
      day: 30
    }, {
      month: 10,
      day: 18
    }, {
      month: 11,
      day: 7
    }, {
      month: 10,
      day: 27
    }, {
      month: 11,
      day: 15
    }, {
      month: 11,
      day: 4
    }, {
      month: 10,
      day: 24
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 1
    }, {
      month: 10,
      day: 20
    }, {
      month: 11,
      day: 8
    }, {
      month: 10,
      day: 29
    }, {
      month: 10,
      day: 18
    }, {
      month: 11,
      day: 5
    }, {
      month: 10,
      day: 26
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 3
    }, {
      month: 10,
      day: 22
    }, {
      month: 11,
      day: 9
    }, {
      month: 10,
      day: 30
    }, {
      month: 10,
      day: 19
    }, {
      month: 11,
      day: 7
    }, {
      month: 10,
      day: 27
    }, {
      month: 11,
      day: 15
    }, {
      month: 11,
      day: 4
    }, {
      month: 10,
      day: 23
    }, {
      month: 11,
      day: 11
    }, {
      month: 10,
      day: 31
    }, {
      month: 10,
      day: 21
    }, {
      month: 11,
      day: 8
    }, {
      month: 10,
      day: 29
    }, {
      month: 10,
      day: 18
    }, {
      month: 11,
      day: 6
    }, {
      month: 10,
      day: 25
    }, {
      month: 11,
      day: 13
    }, {
      month: 11,
      day: 2
    }, {
      month: 10,
      day: 22
    }, {
      month: 11,
      day: 9
    }, {
      month: 10,
      day: 30
    }, {
      month: 10,
      day: 19
    }, {
      month: 11,
      day: 7
    }, {
      month: 10,
      day: 27
    }, {
      month: 11,
      day: 15
    }, {
      month: 11,
      day: 4
    }, {
      month: 10,
      day: 24
    }, {
      month: 11,
      day: 11
    }, {
      month: 10,
      day: 31
    }, {
      month: 10,
      day: 21
    }, {
      month: 11,
      day: 9
    }, {
      month: 10,
      day: 28
    }, {
      month: 10,
      day: 18
    }, {
      month: 11,
      day: 5
    }, {
      month: 10,
      day: 25
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 2
    }, {
      month: 10,
      day: 22
    }, {
      month: 11,
      day: 10
    }, {
      month: 10,
      day: 30
    }, {
      month: 10,
      day: 19
    }, {
      month: 11,
      day: 7
    }, {
      month: 10,
      day: 27
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 3
    }, {
      month: 10,
      day: 23
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 1
    }],
    name: {
      en: 'Bandi Chhorr Divas (Diwali)',
      pa: 'ਬੰਦੀ ਛੋੜ ਦਿਵਸ (ਦੀਵਾਲੀ)',
      type: 'historical'
    }
  },
  gurunanak: {
    dates: [{
      month: 11,
      day: 8
    }, {
      month: 11,
      day: 26
    }, {
      month: 11,
      day: 15
    }, {
      month: 11,
      day: 5
    }, {
      month: 11,
      day: 24
    }, {
      month: 11,
      day: 13
    }, {
      month: 11,
      day: 2
    }, {
      month: 11,
      day: 21
    }, {
      month: 11,
      day: 10
    }, {
      month: 11,
      day: 28
    }, {
      month: 11,
      day: 17
    }, {
      month: 11,
      day: 6
    }, {
      month: 11,
      day: 25
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 4
    }, {
      month: 11,
      day: 23
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 30
    }, {
      month: 11,
      day: 19
    }, {
      month: 11,
      day: 8
    }, {
      month: 11,
      day: 27
    }, {
      month: 11,
      day: 15
    }, {
      month: 11,
      day: 5
    }, {
      month: 11,
      day: 24
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 2
    }, {
      month: 11,
      day: 20
    }, {
      month: 11,
      day: 10
    }, {
      month: 11,
      day: 28
    }, {
      month: 11,
      day: 17
    }, {
      month: 11,
      day: 6
    }, {
      month: 11,
      day: 25
    }, {
      month: 11,
      day: 15
    }, {
      month: 11,
      day: 3
    }, {
      month: 11,
      day: 22
    }, {
      month: 11,
      day: 11
    }, {
      month: 11,
      day: 30
    }, {
      month: 11,
      day: 18
    }, {
      month: 11,
      day: 8
    }, {
      month: 11,
      day: 27
    }, {
      month: 11,
      day: 16
    }, {
      month: 11,
      day: 5
    }, {
      month: 11,
      day: 24
    }, {
      month: 11,
      day: 13
    }, {
      month: 11,
      day: 2
    }, {
      month: 11,
      day: 20
    }, {
      month: 11,
      day: 9
    }, {
      month: 11,
      day: 28
    }, {
      month: 11,
      day: 18
    }, {
      month: 11,
      day: 6
    }, {
      month: 11,
      day: 25
    }, {
      month: 11,
      day: 15
    }, {
      month: 11,
      day: 4
    }, {
      month: 11,
      day: 22
    }, {
      month: 11,
      day: 11
    }, {
      month: 11,
      day: 30
    }, {
      month: 11,
      day: 19
    }, {
      month: 11,
      day: 8
    }, {
      month: 11,
      day: 27
    }, {
      month: 11,
      day: 16
    }, {
      month: 11,
      day: 6
    }, {
      month: 11,
      day: 23
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 2
    }, {
      month: 11,
      day: 20
    }, {
      month: 11,
      day: 9
    }, {
      month: 11,
      day: 28
    }, {
      month: 11,
      day: 18
    }, {
      month: 11,
      day: 7
    }, {
      month: 11,
      day: 25
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 3
    }, {
      month: 11,
      day: 22
    }, {
      month: 11,
      day: 10
    }, {
      month: 11,
      day: 29
    }, {
      month: 11,
      day: 19
    }, {
      month: 11,
      day: 9
    }, {
      month: 11,
      day: 27
    }, {
      month: 11,
      day: 16
    }, {
      month: 11,
      day: 5
    }, {
      month: 11,
      day: 24
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 1
    }, {
      month: 11,
      day: 20
    }, {
      month: 11,
      day: 10
    }, {
      month: 11,
      day: 28
    }, {
      month: 11,
      day: 18
    }, {
      month: 11,
      day: 7
    }, {
      month: 11,
      day: 25
    }, {
      month: 11,
      day: 13
    }, {
      month: 11,
      day: 3
    }, {
      month: 11,
      day: 22
    }, {
      month: 11,
      day: 11
    }, {
      month: 11,
      day: 29
    }, {
      month: 11,
      day: 19
    }, {
      month: 11,
      day: 8
    }, {
      month: 11,
      day: 27
    }, {
      month: 11,
      day: 16
    }],
    name: {
      en: 'Parkash Sri Guru Nanak Dev Ji',
      pa: 'ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਨਾਨਕ ਦੇਵ ਜੀ',
      type: 'gurpurab'
    }
  },
  holla: {
    dates: [{
      month: 3,
      day: 19
    }, {
      month: 3,
      day: 7
    }, {
      month: 3,
      day: 26
    }, {
      month: 3,
      day: 15
    }, {
      month: 3,
      day: 4
    }, {
      month: 3,
      day: 22
    }, {
      month: 3,
      day: 11
    }, {
      month: 3,
      day: 1
    }, {
      month: 3,
      day: 20
    }, {
      month: 3,
      day: 9
    }, {
      month: 3,
      day: 28
    }, {
      month: 3,
      day: 17
    }, {
      month: 3,
      day: 6
    }, {
      month: 3,
      day: 24
    }, {
      month: 3,
      day: 13
    }, {
      month: 3,
      day: 2
    }, {
      month: 3,
      day: 21
    }, {
      month: 3,
      day: 10
    }, {
      month: 3,
      day: 29
    }, {
      month: 3,
      day: 19
    }, {
      month: 3,
      day: 8
    }, {
      month: 3,
      day: 26
    }, {
      month: 3,
      day: 15
    }, {
      month: 3,
      day: 4
    }, {
      month: 3,
      day: 23
    }, {
      month: 3,
      day: 11
    }, {
      month: 3,
      day: 1
    }, {
      month: 3,
      day: 20
    }, {
      month: 3,
      day: 10
    }, {
      month: 3,
      day: 27
    }, {
      month: 3,
      day: 17
    }, {
      month: 3,
      day: 6
    }, {
      month: 3,
      day: 24
    }, {
      month: 3,
      day: 13
    }, {
      month: 3,
      day: 2
    }, {
      month: 3,
      day: 21
    }, {
      month: 3,
      day: 11
    }, {
      month: 3,
      day: 29
    }, {
      month: 3,
      day: 18
    }, {
      month: 3,
      day: 7
    }, {
      month: 3,
      day: 26
    }, {
      month: 3,
      day: 14
    }, {
      month: 3,
      day: 4
    }, {
      month: 3,
      day: 23
    }, {
      month: 3,
      day: 12
    }, {
      month: 3,
      day: 1
    }, {
      month: 3,
      day: 20
    }, {
      month: 3,
      day: 9
    }, {
      month: 3,
      day: 28
    }, {
      month: 3,
      day: 16
    }, {
      month: 3,
      day: 5
    }, {
      month: 3,
      day: 24
    }, {
      month: 3,
      day: 14
    }, {
      month: 3,
      day: 2
    }, {
      month: 3,
      day: 21
    }, {
      month: 3,
      day: 11
    }, {
      month: 3,
      day: 30
    }, {
      month: 3,
      day: 18
    }, {
      month: 3,
      day: 7
    }, {
      month: 3,
      day: 26
    }, {
      month: 3,
      day: 15
    }, {
      month: 3,
      day: 4
    }, {
      month: 3,
      day: 23
    }, {
      month: 3,
      day: 12
    }, {
      month: 3,
      day: 2
    }, {
      month: 3,
      day: 19
    }, {
      month: 3,
      day: 8
    }, {
      month: 3,
      day: 27
    }, {
      month: 3,
      day: 16
    }, {
      month: 3,
      day: 5
    }, {
      month: 3,
      day: 24
    }, {
      month: 3,
      day: 14
    }, {
      month: 3,
      day: 3
    }, {
      month: 3,
      day: 21
    }, {
      month: 3,
      day: 10
    }, {
      month: 3,
      day: 29
    }, {
      month: 3,
      day: 18
    }, {
      month: 3,
      day: 6
    }, {
      month: 3,
      day: 25
    }, {
      month: 3,
      day: 15
    }, {
      month: 3,
      day: 5
    }, {
      month: 3,
      day: 23
    }, {
      month: 3,
      day: 12
    }, {
      month: 3,
      day: 1
    }, {
      month: 3,
      day: 20
    }, {
      month: 3,
      day: 8
    }, {
      month: 3,
      day: 27
    }, {
      month: 3,
      day: 16
    }, {
      month: 3,
      day: 6
    }, {
      month: 3,
      day: 24
    }, {
      month: 3,
      day: 14
    }, {
      month: 3,
      day: 3
    }, {
      month: 3,
      day: 22
    }, {
      month: 3,
      day: 10
    }, {
      month: 3,
      day: 28
    }, {
      month: 3,
      day: 18
    }, {
      month: 3,
      day: 7
    }, {
      month: 3,
      day: 26
    }],
    name: {
      en: 'Holla Mohalla',
      pa: 'ਹੋਲਾ ਮਹੱਲਾ',
      type: 'historical'
    }
  },
  kabeer: {
    dates: [{
      month: 6,
      day: 14
    }, {
      month: 6,
      day: 3
    }, {
      month: 6,
      day: 22
    }, {
      month: 6,
      day: 11
    }, {
      month: 6,
      day: 30
    }, {
      month: 6,
      day: 18
    }, {
      month: 6,
      day: 7
    }, {
      month: 6,
      day: 26
    }, {
      month: 6,
      day: 15
    }, {
      month: 6,
      day: 4
    }, {
      month: 6,
      day: 23
    }, {
      month: 6,
      day: 13
    }, {
      month: 6,
      day: 2
    }, {
      month: 6,
      day: 20
    }, {
      month: 6,
      day: 9
    }, {
      month: 6,
      day: 28
    }, {
      month: 6,
      day: 17
    }, {
      month: 6,
      day: 5
    }, {
      month: 6,
      day: 24
    }, {
      month: 6,
      day: 14
    }, {
      month: 6,
      day: 4
    }, {
      month: 6,
      day: 22
    }, {
      month: 6,
      day: 11
    }, {
      month: 6,
      day: 29
    }, {
      month: 6,
      day: 18
    }, {
      month: 6,
      day: 7
    }, {
      month: 6,
      day: 26
    }, {
      month: 6,
      day: 15
    }, {
      month: 6,
      day: 5
    }, {
      month: 6,
      day: 23
    }, {
      month: 6,
      day: 12
    }, {
      month: 6,
      day: 2
    }, {
      month: 6,
      day: 20
    }, {
      month: 6,
      day: 8
    }, {
      month: 6,
      day: 27
    }, {
      month: 6,
      day: 17
    }, {
      month: 6,
      day: 6
    }, {
      month: 6,
      day: 24
    }, {
      month: 6,
      day: 14
    }, {
      month: 6,
      day: 3
    }, {
      month: 6,
      day: 22
    }, {
      month: 6,
      day: 10
    }, {
      month: 6,
      day: 29
    }, {
      month: 6,
      day: 18
    }, {
      month: 6,
      day: 8
    }, {
      month: 6,
      day: 26
    }, {
      month: 6,
      day: 15
    }, {
      month: 6,
      day: 5
    }, {
      month: 6,
      day: 24
    }, {
      month: 6,
      day: 12
    }, {
      month: 6,
      day: 1
    }, {
      month: 6,
      day: 20
    }, {
      month: 6,
      day: 9
    }, {
      month: 6,
      day: 27
    }, {
      month: 6,
      day: 17
    }, {
      month: 6,
      day: 6
    }, {
      month: 6,
      day: 25
    }, {
      month: 6,
      day: 14
    }, {
      month: 6,
      day: 3
    }, {
      month: 6,
      day: 21
    }, {
      month: 6,
      day: 11
    }, {
      month: 6,
      day: 28
    }, {
      month: 6,
      day: 18
    }, {
      month: 6,
      day: 8
    }, {
      month: 6,
      day: 27
    }, {
      month: 6,
      day: 15
    }, {
      month: 6,
      day: 4
    }, {
      month: 6,
      day: 23
    }, {
      month: 6,
      day: 12
    }, {
      month: 5,
      day: 31
    }, {
      month: 6,
      day: 19
    }, {
      month: 6,
      day: 9
    }, {
      month: 6,
      day: 28
    }, {
      month: 6,
      day: 17
    }, {
      month: 6,
      day: 6
    }, {
      month: 6,
      day: 25
    }, {
      month: 6,
      day: 14
    }, {
      month: 6,
      day: 2
    }, {
      month: 6,
      day: 21
    }, {
      month: 6,
      day: 10
    }, {
      month: 6,
      day: 29
    }, {
      month: 6,
      day: 18
    }, {
      month: 6,
      day: 8
    }, {
      month: 6,
      day: 27
    }, {
      month: 6,
      day: 16
    }, {
      month: 6,
      day: 4
    }, {
      month: 6,
      day: 22
    }, {
      month: 6,
      day: 12
    }, {
      month: 6,
      day: 1
    }, {
      month: 6,
      day: 19
    }, {
      month: 6,
      day: 9
    }, {
      month: 6,
      day: 28
    }, {
      month: 6,
      day: 17
    }, {
      month: 6,
      day: 6
    }, {
      month: 6,
      day: 24
    }, {
      month: 6,
      day: 13
    }, {
      month: 6,
      day: 3
    }, {
      month: 6,
      day: 22
    }],
    name: {
      en: 'Birthday Bhagat Kabeer Ji',
      pa: 'ਜਨਮ ਭਗਤ ਕਬੀਰ ਜੀ',
      type: 'bhagat'
    }
  },
  naamdev: {
    dates: [{
      month: 11,
      day: 4
    }, {
      month: 11,
      day: 22
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 2
    }, {
      month: 11,
      day: 21
    }, {
      month: 11,
      day: 9
    }, {
      month: 10,
      day: 29
    }, {
      month: 11,
      day: 17
    }, {
      month: 11,
      day: 6
    }, {
      month: 11,
      day: 24
    }, {
      month: 11,
      day: 13
    }, {
      month: 11,
      day: 3
    }, {
      month: 11,
      day: 22
    }, {
      month: 11,
      day: 11
    }, {
      month: 10,
      day: 31
    }, {
      month: 11,
      day: 19
    }, {
      month: 11,
      day: 8
    }, {
      month: 11,
      day: 25
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 4
    }, {
      month: 11,
      day: 23
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 2
    }, {
      month: 11,
      day: 20
    }, {
      month: 11,
      day: 10
    }, {
      month: 10,
      day: 28
    }, {
      month: 11,
      day: 16
    }, {
      month: 11,
      day: 5
    }, {
      month: 11,
      day: 24
    }, {
      month: 11,
      day: 13
    }, {
      month: 11,
      day: 3
    }, {
      month: 11,
      day: 22
    }, {
      month: 11,
      day: 11
    }, {
      month: 10,
      day: 30
    }, {
      month: 11,
      day: 18
    }, {
      month: 11,
      day: 7
    }, {
      month: 11,
      day: 26
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 4
    }, {
      month: 11,
      day: 23
    }, {
      month: 11,
      day: 13
    }, {
      month: 11,
      day: 1
    }, {
      month: 11,
      day: 20
    }, {
      month: 11,
      day: 9
    }, {
      month: 10,
      day: 29
    }, {
      month: 11,
      day: 16
    }, {
      month: 11,
      day: 5
    }, {
      month: 11,
      day: 24
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 3
    }, {
      month: 11,
      day: 22
    }, {
      month: 11,
      day: 11
    }, {
      month: 10,
      day: 30
    }, {
      month: 11,
      day: 17
    }, {
      month: 11,
      day: 7
    }, {
      month: 11,
      day: 26
    }, {
      month: 11,
      day: 15
    }, {
      month: 11,
      day: 4
    }, {
      month: 11,
      day: 23
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 1
    }, {
      month: 11,
      day: 19
    }, {
      month: 11,
      day: 8
    }, {
      month: 10,
      day: 29
    }, {
      month: 11,
      day: 17
    }, {
      month: 11,
      day: 5
    }, {
      month: 11,
      day: 25
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 3
    }, {
      month: 11,
      day: 21
    }, {
      month: 11,
      day: 10
    }, {
      month: 10,
      day: 30
    }, {
      month: 11,
      day: 18
    }, {
      month: 11,
      day: 7
    }, {
      month: 11,
      day: 26
    }, {
      month: 11,
      day: 16
    }, {
      month: 11,
      day: 5
    }, {
      month: 11,
      day: 23
    }, {
      month: 11,
      day: 12
    }, {
      month: 11,
      day: 1
    }, {
      month: 11,
      day: 19
    }, {
      month: 11,
      day: 8
    }, {
      month: 10,
      day: 29
    }, {
      month: 11,
      day: 17
    }, {
      month: 11,
      day: 6
    }, {
      month: 11,
      day: 24
    }, {
      month: 11,
      day: 14
    }, {
      month: 11,
      day: 2
    }, {
      month: 11,
      day: 21
    }, {
      month: 11,
      day: 9
    }, {
      month: 10,
      day: 30
    }, {
      month: 11,
      day: 18
    }, {
      month: 11,
      day: 8
    }, {
      month: 11,
      day: 26
    }, {
      month: 11,
      day: 15
    }, {
      month: 11,
      day: 4
    }, {
      month: 11,
      day: 23
    }, {
      month: 11,
      day: 12
    }],
    name: {
      en: 'Birthday Bhagat Naamdev Ji',
      pa: 'ਜਨਮ ਭਗਤ ਨਾਮਦੇਵ ਜੀ',
      type: 'bhagat'
    }
  },
  ravidaas: {
    dates: [{
      month: 2,
      day: 16
    }, {
      month: 2,
      day: 6
    }, {
      month: 2,
      day: 24
    }, {
      month: 2,
      day: 13
    }, {
      month: 2,
      day: 2
    }, {
      month: 2,
      day: 21
    }, {
      month: 2,
      day: 9
    }, {
      month: 1,
      day: 30
    }, {
      month: 2,
      day: 18
    }, {
      month: 2,
      day: 7
    }, {
      month: 2,
      day: 25
    }, {
      month: 2,
      day: 14
    }, {
      month: 2,
      day: 3
    }, {
      month: 2,
      day: 22
    }, {
      month: 2,
      day: 10
    }, {
      month: 1,
      day: 31
    }, {
      month: 2,
      day: 19
    }, {
      month: 2,
      day: 9
    }, {
      month: 2,
      day: 27
    }, {
      month: 2,
      day: 16
    }, {
      month: 2,
      day: 5
    }, {
      month: 2,
      day: 24
    }, {
      month: 2,
      day: 12
    }, {
      month: 2,
      day: 1
    }, {
      month: 2,
      day: 20
    }, {
      month: 2,
      day: 10
    }, {
      month: 1,
      day: 30
    }, {
      month: 2,
      day: 18
    }, {
      month: 2,
      day: 7
    }, {
      month: 2,
      day: 26
    }, {
      month: 2,
      day: 14
    }, {
      month: 2,
      day: 3
    }, {
      month: 2,
      day: 22
    }, {
      month: 2,
      day: 11
    }, {
      month: 1,
      day: 31
    }, {
      month: 2,
      day: 19
    }, {
      month: 2,
      day: 9
    }, {
      month: 2,
      day: 27
    }, {
      month: 2,
      day: 15
    }, {
      month: 2,
      day: 4
    }, {
      month: 2,
      day: 23
    }, {
      month: 2,
      day: 13
    }, {
      month: 2,
      day: 1
    }, {
      month: 2,
      day: 20
    }, {
      month: 2,
      day: 10
    }, {
      month: 1,
      day: 30
    }, {
      month: 2,
      day: 17
    }, {
      month: 2,
      day: 6
    }, {
      month: 2,
      day: 25
    }, {
      month: 2,
      day: 14
    }, {
      month: 2,
      day: 3
    }, {
      month: 2,
      day: 22
    }, {
      month: 2,
      day: 11
    }, {
      month: 2,
      day: 1
    }, {
      month: 2,
      day: 19
    }, {
      month: 2,
      day: 8
    }, {
      month: 2,
      day: 27
    }, {
      month: 2,
      day: 16
    }, {
      month: 2,
      day: 4
    }, {
      month: 2,
      day: 23
    }, {
      month: 2,
      day: 13
    }, {
      month: 2,
      day: 2
    }, {
      month: 2,
      day: 20
    }, {
      month: 2,
      day: 10
    }, {
      month: 1,
      day: 30
    }, {
      month: 2,
      day: 18
    }, {
      month: 2,
      day: 6
    }, {
      month: 2,
      day: 25
    }, {
      month: 2,
      day: 14
    }, {
      month: 2,
      day: 4
    }, {
      month: 2,
      day: 22
    }, {
      month: 2,
      day: 11
    }, {
      month: 2,
      day: 1
    }, {
      month: 2,
      day: 19
    }, {
      month: 2,
      day: 7
    }, {
      month: 2,
      day: 26
    }, {
      month: 2,
      day: 15
    }, {
      month: 2,
      day: 5
    }, {
      month: 2,
      day: 23
    }, {
      month: 2,
      day: 13
    }, {
      month: 2,
      day: 2
    }, {
      month: 2,
      day: 21
    }, {
      month: 2,
      day: 9
    }, {
      month: 1,
      day: 29
    }, {
      month: 2,
      day: 17
    }, {
      month: 2,
      day: 6
    }, {
      month: 2,
      day: 24
    }, {
      month: 2,
      day: 14
    }, {
      month: 2,
      day: 4
    }, {
      month: 2,
      day: 23
    }, {
      month: 2,
      day: 11
    }, {
      month: 1,
      day: 31
    }, {
      month: 2,
      day: 19
    }, {
      month: 2,
      day: 8
    }, {
      month: 2,
      day: 26
    }, {
      month: 2,
      day: 15
    }, {
      month: 2,
      day: 5
    }, {
      month: 2,
      day: 24
    }],
    name: {
      en: 'Birthday Bhagat Ravidaas Ji',
      pa: 'ਜਨਮ ਭਗਤ ਰਵਿਦਾਸ ਜੀ',
      type: 'bhagat'
    }
  }
};

/***/ }),

/***/ 291:
/***/ ((module) => {

module.exports = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];

/***/ }),

/***/ 373:
/***/ ((module) => {

module.exports = [{
  pa: 'ਚੇਤ',
  en: 'Chet'
}, {
  pa: 'ਵੈਸਾਖ',
  en: 'Vaisakh'
}, {
  pa: 'ਜੇਠ',
  en: 'Jeth'
}, {
  pa: 'ਹਾੜ',
  en: 'Harh'
}, {
  pa: 'ਸਾਵਣ',
  en: 'Savan'
}, {
  pa: 'ਭਾਦੋਂ',
  en: 'Bhadon'
}, {
  pa: 'ਅੱਸੂ',
  en: 'Assu'
}, {
  pa: 'ਕੱਤਕ',
  en: 'Katak'
}, {
  pa: 'ਮੱਘਰ',
  en: 'Maghar'
}, {
  pa: 'ਪੋਹ',
  en: 'Poh'
}, {
  pa: 'ਮਾਘ',
  en: 'Magh'
}, {
  pa: 'ਫੱਗਣ',
  en: 'Phagun'
}];

/***/ }),

/***/ 399:
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

function _toConsumableArray(r) { return _arrayWithoutHoles(r) || _iterableToArray(r) || _unsupportedIterableToArray(r) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _iterableToArray(r) { if ("undefined" != typeof Symbol && null != r[Symbol.iterator] || null != r["@@iterator"]) return Array.from(r); }
function _arrayWithoutHoles(r) { if (Array.isArray(r)) return _arrayLikeToArray(r); }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
var findMovableGurpurab = __webpack_require__(254);
var getNanakshahiDate = __webpack_require__(917);
var _require = __webpack_require__(56),
  gurpurabs = _require.gurpurabs;

/**
 * Returns all Gurpurabs for a Date
 * @param {Object} [gregorianDate=new Date()] JavaScript Date() Object
 * @return {Array} Gurpurabs for the day with Date and name in English and Punjabi
 * @example getGurpurabsForDay( new Date() )
 */
function getGurpurabsForDay() {
  var gregorianDate = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : new Date();
  // Get Date Info
  var nanakshahi = getNanakshahiDate(gregorianDate);
  var _nanakshahi$englishDa = nanakshahi.englishDate,
    month = _nanakshahi$englishDa.month,
    date = _nanakshahi$englishDa.date;

  // Get Fesitval date for specific Nanakshahi Month
  var calendarDates = gurpurabs[month];

  // Check if there is Fesitval on Date
  var gurpurabsList = [];
  calendarDates.every(function (value) {
    if (value.date === date) {
      gurpurabsList = _toConsumableArray(value.gurpurabs);
      return false;
    }
    return true;
  });

  // Get Movable Gurpurabs
  var movableDate;
  var movableGurpurabs = ['ravidaas', 'holla', 'kabeer', 'bandichhorr', 'naamdev', 'gurunanak'];
  movableGurpurabs.every(function (value) {
    movableDate = findMovableGurpurab(value, gregorianDate.getFullYear());
    if (movableDate.gregorianDate.getMonth() === gregorianDate.getMonth() && movableDate.gregorianDate.getDate() === gregorianDate.getDate()) {
      gurpurabsList.push(movableDate.name);
      return false;
    }
    return true;
  });
  return gurpurabsList;
}
module.exports = getGurpurabsForDay;

/***/ }),

/***/ 435:
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var findMovableGurpurab = __webpack_require__(254);
var getDateFromNanakshahi = __webpack_require__(853);
var getNanakshahiDate = __webpack_require__(917);
var _require = __webpack_require__(56),
  gurpurabs = _require.gurpurabs,
  months = _require.months;
var _require2 = __webpack_require__(525),
  leapYear = _require2.leapYear,
  toGurmukhiNum = _require2.toGurmukhiNum;

/**
 * Returns all Gurpurabs for a Nanakshahi Month
 * @param {!number} month Nanakshahi Month, 1-12
 * @param {!number} [year] Nanakshahi Year. Default is current Nanakshahi Year.
 * @return {Object} Gurpurabs for the month with Date and name in English and Punjabi
 * @example getGurpurabsForMonth( 1 )
 */
function getGurpurabsForMonth(month) {
  var year = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : getNanakshahiDate().englishDate.year;
  // Get Fesitval dates for specific Nanakshahi Month
  var calendarDates = gurpurabs[month];

  // Go though list and add dates
  var gurpurabsList = [];
  calendarDates.forEach(function (value) {
    var nanakshahiDate = getDateFromNanakshahi(year, month, value.date);
    gurpurabsList.push({
      date: {
        gregorianDate: nanakshahiDate.gregorianDate,
        nanakshahiDate: {
          englishDate: {
            date: nanakshahiDate.englishDate.date,
            day: nanakshahiDate.englishDate.day
          },
          punjabiDate: {
            date: nanakshahiDate.punjabiDate.date,
            day: nanakshahiDate.punjabiDate.day
          }
        }
      },
      gurpurabs: value.gurpurabs
    });
  });

  // Length of Nanakshahi Months
  var monthLength = [31, 31, 31, 31, 31, 30, 30, 30, 30, 30, 30, leapYear(year) ? 31 : 30 // Phagun Leap Check
  ];

  // Check all moveable gurpurabs fall in Nanakshahi month
  var startMonth = getDateFromNanakshahi(year, month, 1).gregorianDate;
  var movableGurpurabs = ['ravidaas', 'holla', 'kabeer', 'bandichhorr', 'naamdev', 'gurunanak'];
  movableGurpurabs.forEach(function (value) {
    var _findMovableGurpurab = findMovableGurpurab(value, startMonth.getFullYear()),
      gregorianDate = _findMovableGurpurab.gregorianDate,
      name = _findMovableGurpurab.name;
    var diffDays = (gregorianDate.getTime() - startMonth.getTime()) / (1000 * 60 * 60 * 24);
    if (diffDays < monthLength[month - 1] && diffDays >= 0) {
      var _getNanakshahiDate = getNanakshahiDate(gregorianDate),
        englishDate = _getNanakshahiDate.englishDate,
        punjabiDate = _getNanakshahiDate.punjabiDate;
      gurpurabsList.push({
        date: {
          gregorianDate: gregorianDate,
          nanakshahiDate: {
            englishDate: {
              date: englishDate.date,
              day: englishDate.day
            },
            punjabiDate: {
              date: punjabiDate.date,
              day: punjabiDate.day
            }
          }
        },
        gurpurabs: [name]
      });
    }
  });

  // Sort gurpurabs based on Nanakshahi Date
  gurpurabsList.sort(function (a, b) {
    return a.date.nanakshahiDate.englishDate.date - b.date.nanakshahiDate.englishDate.date;
  });

  // Add month metadata
  var nanakshahiMonth = {
    englishMonth: {
      month: month,
      monthName: months[month - 1].en,
      year: year
    },
    punjabiMonth: {
      month: toGurmukhiNum(month),
      monthName: months[month - 1].pa,
      year: toGurmukhiNum(year)
    }
  };
  return {
    nanakshahiMonth: nanakshahiMonth,
    gurpurabs: gurpurabsList
  };
}
module.exports = getGurpurabsForMonth;

/***/ }),

/***/ 525:
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var leapYear = __webpack_require__(178);
var toGurmukhiNum = __webpack_require__(904);
module.exports = {
  leapYear: leapYear,
  toGurmukhiNum: toGurmukhiNum
};

/***/ }),

/***/ 853:
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var _require = __webpack_require__(525),
  leapYear = _require.leapYear,
  toGurmukhiNum = _require.toGurmukhiNum;
var _require2 = __webpack_require__(56),
  months = _require2.months,
  weekdays = _require2.weekdays;

/**
 * Converts Nanakshahi Date into the Gregorian Calendar
 * @param {!number} year Nanakshahi Year
 * @param {!number} month Nanakshahi Month, 1-12
 * @param {!number} date Nanakshahi Day
 * @return {Object} Gregorian Date + Nanakshahi Date in English and Punjabi
 * @example getDateFromNanakshahi( 550, 10, 23 )
 */
function getDateFromNanakshahi(year, month, date) {
  // Check if before 535 N.S. (Nanakshahi Adoption)
  if (year < 535) {
    throw new RangeError('Nanakshahi Date Out of Range');
  }

  // NS Month Offsets
  var monthOffsets = [14, 14, 15, 15, 16, 16, 15, 15, 14, 14, 13, 12];

  // Date Object
  var gregorianDate = new Date(
  // Calculate Gregorian Year
  month < 11 ? year + 1468 : year + 1469,
  // Set month start from Nanakshahi [0..11]
  month < 11 ? month + 1 : month - 11,
  // Add days to months
  monthOffsets[month - 1] + (date - 1));

  // Get Day of Week
  var weekday = gregorianDate.getDay();
  return {
    gregorianDate: gregorianDate,
    englishDate: {
      month: month,
      monthName: months[month - 1].en,
      date: date,
      year: year,
      day: weekdays[weekday].en,
      dayShort: weekdays[weekday].enShort
    },
    punjabiDate: {
      month: toGurmukhiNum(month),
      monthName: months[month - 1].pa,
      date: toGurmukhiNum(date),
      year: toGurmukhiNum(year),
      day: weekdays[weekday].pa,
      dayShort: weekdays[weekday].paShort
    },
    leapYear: leapYear(year)
  };
}
module.exports = getDateFromNanakshahi;

/***/ }),

/***/ 855:
/***/ ((module) => {

module.exports = {
  1: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਨਵਾਂ ਸਾਲ',
      en: 'Nanakshahi New Year',
      type: 'calendar'
    }, {
      pa: 'ਅਰੰਭ ਚੇਤ',
      en: 'Beginning of Chet',
      type: 'calendar'
    }, {
      pa: 'ਗੁਰਗੱਦੀ ਸ੍ਰੀ ਗੁਰੂ ਹਰਿਰਾਇ ਸਾਹਿਬ ਜੀ',
      en: 'Gurgaddi Sri Guru HarRai Sahib Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 2,
    gurpurabs: [{
      pa: 'ਦਿੱਲੀ ਫ਼ਤਹ ਭਾਈ ਬਘੇਲ ਸਿੰਘ',
      en: 'Delhi Fateh Bhai Baghel Singh',
      type: 'historical'
    }]
  }, {
    date: 6,
    gurpurabs: [{
      pa: 'ਜੋਤੀ-ਜੋਤਿ ਸ੍ਰੀ ਗੁਰੂ ਹਰਿਗੋਬਿੰਦ ਸਾਹਿਬ ਜੀ',
      en: 'Joti Jot Sri Guru Hargobind Sahib Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 12,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਭਾਈ ਸੁਬੇਗ ਸਿੰਘ ਜੀ ਅਤੇ ਭਾਈ ਸ਼ਾਹਬਾਜ਼ ਸਿੰਘ ਜੀ',
      en: 'Shaheedi Bhai Subeg Singh Ji and Bhai Shahbaz Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 27,
    gurpurabs: [{
      pa: 'ਜਨਮ ਸਾਹਿਬਜ਼ਾਦਾ ਬਾਬਾ ਜੁਝਾਰ ਸਿੰਘ ਜੀ',
      en: 'Birthday Sahibzada Baba Jujhar Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 31,
    gurpurabs: [{
      pa: 'ਵੈਸਾਖੀ 1978 ਦਾ ਸ਼ਹੀਦੀ ਸਾਕਾ (ਸ੍ਰੀ ਅੰਮ੍ਰਿਤਸਰ)',
      en: 'Vaisakhi 1978 Shaheedi Saka (Sri Amritsar)',
      type: 'historical'
    }]
  }],
  2: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਵੈਸਾਖ',
      en: 'Beginning of Vaisakh',
      type: 'calendar'
    }, {
      pa: 'ਖ਼ਾਲਸਾ ਸਾਜਣਾ ਦਿਵਸ (ਵੈਸਾਖੀ)',
      en: 'Khalsa Sajna Divas (Vaisakhi)',
      type: 'historical'
    }]
  }, {
    date: 3,
    gurpurabs: [{
      pa: 'ਗੁਰਗੱਦੀ ਸ੍ਰੀ ਗੁਰੂ ਅਮਰਦਾਸ ਜੀ',
      en: 'Gurgaddi Sri Guru Amardas Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਜੋਤੀ-ਜੋਤਿ ਸ੍ਰੀ ਗੁਰੂ ਅੰਗਦ ਦੇਵ ਜੀ',
      en: 'Joti Jot Sri Guru Angad Dev Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਗੁਰਗੱਦੀ ਸ੍ਰੀ ਗੁਰੂ ਤੇਗ਼ ਬਹਾਦਰ ਸਾਹਿਬ ਜੀ',
      en: 'Gurgaddi Sri Guru Tegh Bahadur Sahib Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਜੋਤੀ-ਜੋਤਿ ਸ੍ਰੀ ਗੁਰੂ ਹਰਿਕ੍ਰਿਸ਼ਨ ਸਾਹਿਬ ਜੀ',
      en: 'Joti Jot Sri Guru Harkrishan Sahib Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 5,
    gurpurabs: [{
      pa: 'ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਅੰਗਦ ਦੇਵ ਜੀ',
      en: 'Parkash Sri Guru Angad Dev Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਤੇਗ਼ ਬਹਾਦਰ ਸਾਹਿਬ ਜੀ',
      en: 'Parkash Sri Guru Tegh Bahadur Sahib Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 8,
    gurpurabs: [{
      pa: 'ਜਨਮ ਭਗਤ ਧੰਨਾ ਜੀ',
      en: 'Birthday Bhagat Dhanna Ji',
      type: 'bhagat'
    }]
  }, {
    date: 19,
    gurpurabs: [{
      pa: 'ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਅਰਜਨ ਦੇਵ ਜੀ',
      en: 'Parkash Sri Guru Arjan Dev Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 21,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਚਾਲੀ ਮੁਕਤੇ (ਮੁਕਤਸਰ ਸਾਹਿਬ)',
      en: 'Shaheedi Forty Mukte (Mukatsar)',
      type: 'historical'
    }]
  }],
  3: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਜੇਠ',
      en: 'Beginning of Jeth',
      type: 'calendar'
    }]
  }, {
    date: 3,
    gurpurabs: [{
      pa: 'ਛੋਟਾ ਘੱਲੂਘਾਰਾ (ਕਾਹਨੂੰਵਾਨ)',
      en: 'Chhota Ghalughara',
      type: 'historical'
    }]
  }, {
    date: 8,
    gurpurabs: [{
      pa: 'ਸਾਕਾ ਪਾਉਂਟਾ ਸਾਹਿਬ',
      en: 'Saka Paonta Sahib',
      type: 'historical'
    }]
  }, {
    date: 9,
    gurpurabs: [{
      pa: 'ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਅਮਰਦਾਸ ਜੀ',
      en: 'Parkash Sri Guru Amardas Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 15,
    gurpurabs: [{
      pa: 'ਸਰਹਿੰਦ ਫ਼ਤਹ ਬਾਬਾ ਬੰਦਾ ਸਿੰਘ ਜੀ ਬਹਾਦਰ',
      en: 'Sirhind Fateh Baba Banda Singh Ji Bahadur',
      type: 'historical'
    }]
  }, {
    date: 18,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਭਾਈ ਮਹਿੰਗਾ ਸਿੰਘ ਬੱਬਰ',
      en: 'Shaheedi Bhai Mehnga Singh Babbar',
      type: 'historical'
    }]
  }, {
    date: 21,
    gurpurabs: [{
      pa: "ਸ੍ਰੀ ਅਕਾਲ ਤਖ਼ਤ ਸਾਹਿਬ 'ਤੇ ਹਮਲਾ (1984)",
      en: '1984 Attack on Sri Akal Takht Sahib',
      type: 'historical'
    }]
  }, {
    date: 22,
    gurpurabs: [{
      pa: 'ਜਨਮ ਪਿਆਰੇ ਭਾਈ ਮੁਹਕਮ ਸਿੰਘ ਜੀ',
      en: 'Birthday Pyare Bhai Mohkam Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 23,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਬਾਬਾ ਜਰਨੈਲ ਸਿੰਘ ਜੀ ਭਿੰਡਰਾਂਵਾਲੇ',
      en: 'Shaheedi Baba Jarnail Singh Ji Bhindranwale',
      type: 'historical'
    }]
  }, {
    date: 28,
    gurpurabs: [{
      pa: 'ਗੁਰਗੱਦੀ ਸ੍ਰੀ ਗੁਰੂ ਹਰਿਗੋਬਿੰਦ ਸਾਹਿਬ ਜੀ',
      en: 'Gurgaddi Sri Guru Hargobind Sahib Ji',
      type: 'gurpurab'
    }]
  }],
  4: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਹਾੜ',
      en: 'Beginning of Harh',
      type: 'calendar'
    }]
  }, {
    date: 2,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਦਿਵਸ ਸ੍ਰੀ ਗੁਰੂ ਅਰਜਨ ਦੇਵ ਜੀ',
      en: 'Shaheedi Day Sri Guru Arjan Dev Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 4,
    gurpurabs: [{
      pa: 'ਜਨਮ ਪਿਆਰੇ ਭਾਈ ਸਾਹਿਬ ਸਿੰਘ ਜੀ',
      en: 'Birthday Pyare Bhai Sahib Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 11,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਬਾਬਾ ਬੰਦਾ ਸਿੰਘ ਜੀ ਬਹਾਦਰ',
      en: 'Shaheedi Baba Banda Singh Ji Bahadur',
      type: 'historical'
    }]
  }, {
    date: 15,
    gurpurabs: [{
      pa: 'ਦਿਹਾਂਤ ਰਾਜਾ ਰਣਜੀਤ ਸਿੰਘ',
      en: 'Death of Raja Ranjit Singh',
      type: 'historical'
    }]
  }, {
    date: 18,
    gurpurabs: [{
      pa: 'ਸਿਰਜਣਾ ਦਿਵਸ ਸ੍ਰੀ ਅਕਾਲ ਤਖ਼ਤ ਸਾਹਿਬ',
      en: 'Foundation Day Sri Akal Takht Sahib',
      type: 'historical'
    }]
  }, {
    date: 21,
    gurpurabs: [{
      pa: 'ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਹਰਿਗੋਬਿੰਦ ਸਾਹਿਬ ਜੀ',
      en: 'Parkash Sri Guru Hargobind Sahib Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 25,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਭਾਈ ਮਨੀ ਸਿੰਘ ਜੀ',
      en: 'Shaheedi Bhai Mani Singh Ji',
      type: 'historical'
    }]
  }],
  5: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਸਾਵਣ',
      en: 'Beginning of Savan',
      type: 'calendar'
    }, {
      pa: 'ਸ਼ਹੀਦੀ ਭਾਈ ਤਾਰੂ ਸਿੰਘ ਜੀ',
      en: 'Shaheedi Bhai Taru Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 5,
    gurpurabs: [{
      pa: 'ਅਕਾਲ ਚਲਾਣਾ ਸ਼ੇਖ਼ ਫ਼ਰੀਦ ਜੀ',
      en: 'Death of Sheikh Fareed Ji',
      type: 'bhagat'
    }]
  }, {
    date: 6,
    gurpurabs: [{
      pa: 'ਮੀਰੀ-ਪੀਰੀ ਦਿਵਸ - ਸ੍ਰੀ ਗੁਰੂ ਹਰਿਗੋਬਿੰਦ ਸਾਹਿਬ ਜੀ',
      en: 'Miri-Piri Day - Sri Guru Hargobind Sahib Ji',
      type: 'historical'
    }]
  }, {
    date: 8,
    gurpurabs: [{
      pa: 'ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਹਰਿਕ੍ਰਿਸ਼ਨ ਸਾਹਿਬ ਜੀ',
      en: 'Parkash Sri Guru Harkrishan Sahib Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 24,
    gurpurabs: [{
      pa: 'ਮੋਰਚਾ ਗੁਰੂ ਕਾ ਬਾਗ',
      en: 'Morcha Guru Ka Baag',
      type: 'historical'
    }]
  }],
  6: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਭਾਦੋਂ',
      en: 'Beginning of Bhadon',
      type: 'calendar'
    }]
  }, {
    date: 12,
    gurpurabs: [{
      pa: 'ਜਨਮ ਪਿਆਰੇ ਭਾਈ ਦਯਾ ਸਿੰਘ ਜੀ',
      en: 'Birthday Pyare Bhai Daya Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 15,
    gurpurabs: [{
      pa: 'ਵਿਆਹ ਪੁਰਬ ਸ੍ਰੀ ਗੁਰੂ ਨਾਨਕ ਦੇਵ ਜੀ',
      en: 'Marriage Day Sri Guru Nanak Dev Ji',
      type: 'historical'
    }, {
      pa: 'ਸੰਪੂਰਨਤਾ ਦਿਵਸ ਸ੍ਰੀ ਗੁਰੂ ਗ੍ਰੰਥ ਸਾਹਿਬ ਜੀ (ਸ੍ਰੀ ਦਮਦਮਾ ਸਾਹਿਬ)',
      en: 'Completion of Sri Guru Granth Sahib Ji (Sri Damdama Sahib)',
      type: 'historical'
    }, {
      pa: 'ਸ਼ਹੀਦੀ ਭਾਈ ਅਨੋਖ ਸਿੰਘ ਬੱਬਰ',
      en: 'Shaheedi Bhai Anokh Singh Babbar',
      type: 'historical'
    }]
  }, {
    date: 17,
    gurpurabs: [{
      pa: 'ਪਹਿਲਾ ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਗ੍ਰੰਥ ਸਾਹਿਬ ਜੀ (ਸ੍ਰੀ ਦਰਬਾਰ ਸਾਹਿਬ)',
      en: 'First Parkash of Sri Guru Granth Sahib Ji (Sri Darbar Sahib)',
      type: 'gurpurab'
    }]
  }, {
    date: 28,
    gurpurabs: [{
      pa: 'ਸਾਕਾ ਸਾਰਾਗੜ੍ਹੀ',
      en: 'Battle of Saragarhi',
      type: 'historical'
    }]
  }],
  7: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਅੱਸੂ',
      en: 'Beginning of Assu',
      type: 'calendar'
    }]
  }, {
    date: 2,
    gurpurabs: [{
      pa: 'ਗੁਰਗੱਦੀ ਸ੍ਰੀ ਗੁਰੂ ਰਾਮਦਾਸ ਜੀ',
      en: 'Gurgaddi Sri Guru Ramdas Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਜੋਤੀ-ਜੋਤਿ ਸ੍ਰੀ ਗੁਰੂ ਅਮਰਦਾਸ ਜੀ',
      en: 'Joti Jot Sri Guru Amardas Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਗੁਰਗੱਦੀ ਸ੍ਰੀ ਗੁਰੂ ਅਰਜਨ ਦੇਵ ਜੀ',
      en: 'Gurgaddi Sri Guru Arjan Dev Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਜੋਤੀ-ਜੋਤਿ ਸ੍ਰੀ ਗੁਰੂ ਰਾਮਦਾਸ ਜੀ',
      en: 'Joti Jot Sri Guru Ramdas Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 4,
    gurpurabs: [{
      pa: 'ਗੁਰਗੱਦੀ ਸ੍ਰੀ ਗੁਰੂ ਅੰਗਦ ਦੇਵ ਜੀ',
      en: 'Gurgaddi Sri Guru Angad Dev Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 8,
    gurpurabs: [{
      pa: 'ਜੋਤੀ-ਜੋਤਿ ਸ੍ਰੀ ਗੁਰੂ ਨਾਨਕ ਦੇਵ ਜੀ',
      en: 'Joti Jot Sri Guru Nanak Dev Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 17,
    gurpurabs: [{
      pa: 'ਸਥਾਪਨਾ ਸਿੰਘ ਸਭਾ ਲਹਿਰ',
      en: 'Founding of Singh Sabha Movement',
      type: 'historical'
    }]
  }, {
    date: 25,
    gurpurabs: [{
      pa: 'ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਰਾਮਦਾਸ ਜੀ',
      en: 'Parkash Sri Guru Ramdas Ji',
      type: 'gurpurab'
    }]
  }],
  8: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਕੱਤਕ',
      en: 'Beginning of Katak',
      type: 'calendar'
    }]
  }, {
    date: 6,
    gurpurabs: [{
      pa: 'ਗੁਰਗੱਦੀ ਸ੍ਰੀ ਗੁਰੂ ਹਰਿਕ੍ਰਿਸ਼ਨ ਸਾਹਿਬ ਜੀ',
      en: 'Gurgaddi Sri Guru Harkrishan Sahib Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਜੋਤੀ-ਜੋਤਿ ਸ੍ਰੀ ਗੁਰੂ ਹਰਿਰਾਇ ਸਾਹਿਬ ਜੀ',
      en: 'Joti Jot Sri Guru HarRai Sahib Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਗੁਰਗੱਦੀ ਸ੍ਰੀ ਗੁਰੂ ਗ੍ਰੰਥ ਸਾਹਿਬ ਜੀ',
      en: 'Gurgaddi Sri Guru Granth Sahib Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 7,
    gurpurabs: [{
      pa: 'ਜੋਤੀ-ਜੋਤਿ ਸ੍ਰੀ ਗੁਰੂ ਗੋਬਿੰਦ ਸਿੰਘ ਜੀ',
      en: 'Joti Jot Sri Guru Gobind Singh Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਜਨਮ ਬਾਬਾ ਬੁੱਢਾ ਜੀ (ਕੱਥੂਨੰਗਲ)',
      en: 'Birthday Baba Buddha Ji',
      type: 'historical'
    }, {
      pa: 'ਜਨਮ ਪਿਆਰੇ ਭਾਈ ਧਰਮ ਸਿੰਘ ਜੀ',
      en: 'Birthday Pyare Bhai Dharam Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 14,
    gurpurabs: [{
      pa: 'ਸਾਕਾ ਪੰਜਾ ਸਾਹਿਬ',
      en: 'Saka Panja Sahib',
      type: 'historical'
    }]
  }, {
    date: 17,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਭਾਈ ਬੇਅੰਤ ਸਿੰਘ',
      en: 'Shaheedi Bhai Beant Singh',
      type: 'historical'
    }]
  }, {
    date: 18,
    gurpurabs: [{
      pa: 'ਜਨਮ ਮਾਤਾ ਸਾਹਿਬ ਕੌਰ ਜੀ',
      en: 'Birthday Mata Sahib Kaur Ji',
      type: 'historical'
    }]
  }, {
    date: 30,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਬਾਬਾ ਦੀਪ ਸਿੰਘ ਜੀ',
      en: 'Shaheedi Baba Deep Singh Ji',
      type: 'historical'
    }]
  }],
  9: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਮੱਘਰ',
      en: 'Beginning of Maghar',
      type: 'calendar'
    }]
  }, {
    date: 3,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਸ: ਕਰਤਾਰ ਸਿੰਘ ਸਰਾਭਾ',
      en: 'Shaheedi Kartar Singh Sarabha',
      type: 'historical'
    }]
  }, {
    date: 11,
    gurpurabs: [{
      pa: 'ਗੁਰਗੱਦੀ ਸ੍ਰੀ ਗੁਰੂ ਗੋਬਿੰਦ ਸਿੰਘ ਜੀ',
      en: 'Gurgaddi Sri Guru Gobind Singh Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਸ਼ਹੀਦੀ ਸ੍ਰੀ ਗੁਰੂ ਤੇਗ਼ ਬਹਾਦਰ ਸਾਹਿਬ ਜੀ',
      en: 'Shaheedi Sri Guru Tegh Bahadur Sahib Ji',
      type: 'gurpurab'
    }, {
      pa: 'ਸ਼ਹੀਦੀ ਭਾਈ ਮਤੀ ਦਾਸ ਜੀ, ਭਾਈ ਸਤੀ ਦਾਸ ਜੀ, ਅਤੇ ਭਾਈ ਦਿਆਲਾ ਜੀ',
      en: 'Shaeedi Bhai Mati Das Ji, Bhai Sati Das Ji, and Bhai Dayala Ji',
      type: 'historical'
    }]
  }, {
    date: 13,
    gurpurabs: [{
      pa: 'ਅਕਾਲ ਚਲਾਣਾ ਭਾਈ ਮਰਦਾਨਾ ਜੀ',
      en: 'Death of Bhai Mardana Ji',
      type: 'historical'
    }]
  }, {
    date: 14,
    gurpurabs: [{
      pa: 'ਅਕਾਲ ਚਲਾਣਾ ਬਾਬਾ ਬੁੱਢਾ ਜੀ (ਰਮਦਾਸ)',
      en: 'Death of Baba Buddha Ji',
      type: 'historical'
    }]
  }, {
    date: 15,
    gurpurabs: [{
      pa: 'ਜਨਮ ਸਾਹਿਬਜ਼ਾਦਾ ਬਾਬਾ ਜ਼ੋਰਾਵਰ ਸਿੰਘ ਜੀ',
      en: 'Birthday Sahibzada Baba Zoravar Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 19,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਬਾਬਾ ਗੁਰਬਖ਼ਸ਼ ਸਿੰਘ ਜੀ',
      en: 'Shaheedi Baba Gurbaksh Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 29,
    gurpurabs: [{
      pa: 'ਜਨਮ ਸਾਹਿਬਜ਼ਾਦਾ ਬਾਬਾ ਫ਼ਤਹ ਸਿੰਘ ਜੀ',
      en: 'Birthday Sahibzada Baba Fateh Singh Ji',
      type: 'historical'
    }]
  }],
  10: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਪੋਹ',
      en: 'Beginning of Poh',
      type: 'calendar'
    }]
  }, {
    date: 7,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਬਾਬਾ ਜੀਵਨ ਸਿੰਘ ਜੀ (ਭਾਈ ਜੈਤਾ ਜੀ)',
      en: 'Shaheedi Baba Jeevan Singh Ji (Bhai Jaita Ji)',
      type: 'historical'
    }]
  }, {
    date: 8,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਵੱਡੇ ਸਾਹਿਬਜ਼ਾਦੇ',
      en: 'Shaheedi Elder Sahibzaade',
      type: 'historical'
    }, {
      pa: 'ਸ਼ਹੀਦੀ ਜੋੜ-ਮੇਲਾ ਚਮਕੌਰ ਸਾਹਿਬ',
      en: 'Shaheedi Jorr Mela Chamkaur Sahib',
      type: 'calendar'
    }]
  }, {
    date: 9,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਬਾਬਾ ਸੰਗਤ ਸਿੰਘ ਜੀ',
      en: 'Shaheedi Baba Sangat Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 13,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਛੋਟੇ ਸਾਹਿਬਜ਼ਾਦੇ',
      en: 'Shaheedi Younger Sahibzaade',
      type: 'historical'
    }, {
      pa: 'ਸ਼ਹੀਦੀ ਮਾਤਾ ਗੁਜਰੀ ਜੀ',
      en: 'Shaheedi Mata Gujri Ji',
      type: 'historical'
    }, {
      pa: 'ਸ਼ਹੀਦੀ ਜੋੜ-ਮੇਲਾ ਫ਼ਤਹਗੜ੍ਹ ਸਾਹਿਬ',
      en: 'Shaheedi Jorr Mela Fatehgarh Sahib',
      type: 'calendar'
    }]
  }, {
    date: 23,
    gurpurabs: [{
      pa: 'ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਗੋਬਿੰਦ ਸਿੰਘ ਜੀ',
      en: 'Parkash Sri Guru Gobind Singh Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 24,
    gurpurabs: [{
      pa: 'ਸ਼ਹੀਦੀ ਭਾਈ ਕੇਹਰ ਸਿੰਘ ਜੀ ਅਤੇ ਭਾਈ ਸਤਵੰਤ ਸਿੰਘ ਜੀ',
      en: 'Shaheedi Bhai Kehar Singh Ji and Bhai Satwant Singh Ji',
      type: 'historical'
    }]
  }],
  11: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਮਾਘ',
      en: 'Beginning of Magh',
      type: 'calendar'
    }, {
      pa: 'ਨੀਂਹ-ਪੱਥਰ ਸ੍ਰੀ ਹਰਿਮੰਦਰ ਸਾਹਿਬ (ਸ੍ਰੀ ਅੰਮ੍ਰਿਤਸਰ)',
      en: 'Foundation Day of Sri Harmandir Sahib (Sri Amritsar)',
      type: 'historical'
    }, {
      pa: 'ਜੋੜ-ਮੇਲਾ ਮੁਕਤਸਰ ਸਾਹਿਬ (ਮਾਘੀ)',
      en: 'Jorr Mela Muktsar Sahib (Maghi)',
      type: 'calendar'
    }]
  }, {
    date: 5,
    gurpurabs: [{
      pa: 'ਜਨਮ ਪਿਆਰੇ ਭਾਈ ਹਿੰਮਤ ਸਿੰਘ ਜੀ',
      en: 'Birthday Pyare Bhai Himmat Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 7,
    gurpurabs: [{
      pa: 'ਚਾਬੀਆਂ ਦਾ ਮੋਰਚਾ',
      en: 'Morcha for the Keys to Darbar Sahib',
      type: 'historical'
    }]
  }, {
    date: 14,
    gurpurabs: [{
      pa: 'ਜਨਮ ਬਾਬਾ ਦੀਪ ਸਿੰਘ ਜੀ',
      en: 'Birthday Baba Deep Singh Ji',
      type: 'historical'
    }]
  }, {
    date: 19,
    gurpurabs: [{
      pa: 'ਪ੍ਰਕਾਸ਼ ਸ੍ਰੀ ਗੁਰੂ ਹਰਿਰਾਇ ਸਾਹਿਬ ਜੀ',
      en: 'Parkash Sri Guru HarRai Sahib Ji',
      type: 'gurpurab'
    }]
  }, {
    date: 27,
    gurpurabs: [{
      pa: 'ਵੱਡਾ ਘੱਲੂਘਾਰਾ (ਕੁੱਪ-ਰੋਹੀੜਾ)',
      en: 'Vadda Ghalughara',
      type: 'historical'
    }]
  }, {
    date: 30,
    gurpurabs: [{
      pa: 'ਜਨਮ ਸਾਹਿਬਜ਼ਾਦਾ ਬਾਬਾ ਅਜੀਤ ਸਿੰਘ ਜੀ',
      en: 'Birthday Sahibzada Baba Ajeet Singh Ji',
      type: 'historical'
    }]
  }],
  12: [{
    date: 1,
    gurpurabs: [{
      pa: 'ਅਰੰਭ ਫੱਗਣ',
      en: 'Beginning of Phagun',
      type: 'calendar'
    }]
  }, {
    date: 10,
    gurpurabs: [{
      pa: 'ਸਾਕਾ ਨਨਕਾਣਾ ਸਾਹਿਬ',
      en: 'Saka Nankana Sahib',
      type: 'historical'
    }, {
      pa: 'ਜੈਤੋ ਦਾ ਮੋਰਚਾ',
      en: 'Jaito Morcha',
      type: 'historical'
    }]
  }]
};

/***/ }),

/***/ 861:
/***/ ((module) => {

module.exports = [{
  pa: 'ਐਤਵਾਰ',
  paShort: 'ਐਤ',
  en: 'Aitvaar',
  enShort: 'Ait'
}, {
  pa: 'ਸੋਮਵਾਰ',
  paShort: 'ਸੋਮ',
  en: 'Somvaar',
  enShort: 'Som'
}, {
  pa: 'ਮੰਗਲਵਾਰ',
  paShort: 'ਮੰਗਲ',
  en: 'Mangalvaar',
  enShort: 'Mangal'
}, {
  pa: 'ਬੁੱਧਵਾਰ',
  paShort: 'ਬੁੱਧ',
  en: 'Budhvaar',
  enShort: 'Budh'
}, {
  pa: 'ਵੀਰਵਾਰ',
  paShort: 'ਵੀਰ',
  en: 'Veervaar',
  enShort: 'Veer'
}, {
  pa: 'ਸ਼ੁੱਕਰਵਾਰ',
  paShort: 'ਸ਼ੁੱਕਰ',
  en: 'Shukarvaar',
  enShort: 'Shukar'
}, {
  pa: 'ਸ਼ਨੀਵਾਰ',
  paShort: 'ਸ਼ਨੀ',
  en: 'Shanivaar',
  enShort: 'Shani'
}];

/***/ }),

/***/ 904:
/***/ ((module) => {

/**
 * Convert Number into Gurmukhi Number
 * @param {!number} number Number to Convert
 * @return {string} Number in Gurmukhi
 * @example toGurmukhiNum( 1 )
 * @private
 */
module.exports = function (number) {
  return number.toLocaleString('en-u-nu-guru', {
    useGrouping: false
  });
};

/***/ }),

/***/ 917:
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var _require = __webpack_require__(525),
  leapYear = _require.leapYear,
  toGurmukhiNum = _require.toGurmukhiNum;
var _require2 = __webpack_require__(56),
  months = _require2.months,
  weekdays = _require2.weekdays;

/**
 * Converts given Gregorian Date to the corresponding date in the Nanakshahi Calendar
 * @param {Object} [gregorianDate=new Date()] JavaScript Date() Object
 * @return {Object} Nanakshahi Date in English and Punjabi
 * @example getNanakshahiDate( new Date() )
 */
function getNanakshahiDate() {
  var gregorianDate = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : new Date();
  // NS Month Offsets
  var monthOffsets = [14, 14, 15, 15, 16, 16, 15, 15, 14, 14, 13, 12];

  // Calculate Nanakshahi Year - March 14 (1 Chet) Nanakshahi New Year
  var nsYear = gregorianDate >= new Date(gregorianDate.getFullYear(), 2, 14) ? gregorianDate.getFullYear() - 1468 : gregorianDate.getFullYear() - 1469;

  // Check if before 535 N.S. (Nanakshahi Adoption)
  if (nsYear < 535) {
    throw new RangeError('Nanakshahi Date Out of Range');
  }

  // Calculate Nanakshahi Date
  var nsMonth = (gregorianDate.getMonth() + 9) % 12;
  var nsNextMonth = (nsMonth + 1) % 12;
  var nsDate;
  if (gregorianDate.getDate() >= monthOffsets[nsNextMonth]) {
    nsMonth = nsNextMonth;
    nsDate = gregorianDate.getDate() - monthOffsets[nsNextMonth] + 1;
  } else {
    var gregorianMonths = [31, leapYear(gregorianDate.getFullYear()) ? 29 : 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    nsDate = gregorianMonths[(gregorianDate.getMonth() + 11) % 12] - monthOffsets[nsMonth] + gregorianDate.getDate() + 1;
  }

  // Get Day of Week
  var weekday = gregorianDate.getDay();
  return {
    gregorianDate: gregorianDate,
    englishDate: {
      month: nsMonth + 1,
      monthName: months[nsMonth].en,
      date: nsDate,
      year: nsYear,
      day: weekdays[weekday].en,
      dayShort: weekdays[weekday].enShort
    },
    punjabiDate: {
      month: toGurmukhiNum(nsMonth + 1),
      monthName: months[nsMonth].pa,
      date: toGurmukhiNum(nsDate),
      year: toGurmukhiNum(nsYear),
      day: weekdays[weekday].pa,
      dayShort: weekdays[weekday].paShort
    },
    leapYear: leapYear(nsYear)
  };
}
module.exports = getNanakshahiDate;

/***/ }),

/***/ 987:
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var findMovableGurpurab = __webpack_require__(254);
var getDateFromNanakshahi = __webpack_require__(853);
var getGurpurabsForDay = __webpack_require__(399);
var getGurpurabsForMonth = __webpack_require__(435);
var getNanakshahiDate = __webpack_require__(917);
module.exports = {
  findMovableGurpurab: findMovableGurpurab,
  getDateFromNanakshahi: getDateFromNanakshahi,
  getGurpurabsForDay: getGurpurabsForDay,
  getGurpurabsForMonth: getGurpurabsForMonth,
  getNanakshahiDate: getNanakshahiDate
};

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId](module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	
/******/ 	// startup
/******/ 	// Load entry module and return exports
/******/ 	// This entry module is referenced by other modules so it can't be inlined
/******/ 	var __webpack_exports__ = __webpack_require__(987);
/******/ 	
/******/ 	return __webpack_exports__;
/******/ })()
;
});